@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: Geometry.cpp,v 1.72.2.3 2005/08/22 13:30:32 strk Exp $
+ * $Id: Geometry.cpp,v 1.72.2.5.2.1 2005/11/30 12:33:23 strk Exp $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -36,10 +36,40 @@ namespace geos {
  *
  * \section intro_sec Introduction
  *
- * Geometry Engine Open Source is a C++ port of the Java Topology Suite.
+ * Geometry Engine Open Source is a C++ port of the Java Topology Suite
+ * released under the LGPL license.
+ * It has interfaces for C++, C and python (though swig).
  *
  * \section getstart_sec Getting Started
  *
+ * The recommended low-level interface to the GEOS library
+ * is the simplified \ref c_iface. This will ensure stability of the
+ * API and the ABI of the library during performance improvements
+ * that will likely change classes definitions.
+ *
+ * If you prefer troubles you can use the \ref cpp_iface.
+ */
+
+/** \page c_iface C wrapper interface
+ *
+ * \section Overview
+ *
+ * This is the preferred access method for GEOS.
+ *
+ * It is designed to keep binary compatibility across releases.
+ *
+ * \section Usage
+ *
+ * In order to use the C-API of geos you must link your code against
+ * libgeos_c.so and include the geos_c.h header file, which also contain
+ * function-level documentation.
+ *
+ */
+
+/** \page cpp_iface C++ interface
+ *
+ * \section Overview
+ *
  * Main class is geos::Geometry, from which all geometry types
  * derive.
  *
@@ -60,6 +90,8 @@ namespace geos {
  *
  * For WKT input/output you can use geos::WKTReader and geos::WKTWriter
  *
+ * For WKB input/output you can use geos::WKBReader and geos::WKBWriter
+ *
  * \section exc_sect Exceptions
  *
  * Internal exceptions are thrown as pointers to geos::GEOSException.
@@ -71,6 +103,8 @@ namespace geos {
  */ 
 
 
+
+
 /*
  * Return current GEOS version 
  */
@@ -289,11 +323,11 @@ void Geometry::geometryChanged() {
 }
 
 /**
-* Notifies this Geometry that its Coordinates have been changed by an external
-* party. When #geometryChanged is called, this method will be called for
-* this Geometry and its component Geometries.
-* @see #apply(GeometryComponentFilter)
-*/
+ * Notifies this Geometry that its Coordinates have been changed by an external
+ * party. When geometryChanged is called, this method will be called for
+ * this Geometry and its component Geometries.
+ * @see apply(GeometryComponentFilter *)
+ */
 void Geometry::geometryChangedAction() {
 	delete envelope;
 	envelope=NULL;
@@ -613,7 +647,7 @@ Geometry::Union(const Geometry *other) const
 		int ngeoms, i;
 		vector<Geometry *> *v = new vector<Geometry *>();
 
-		if ( coll = dynamic_cast<const GeometryCollection *>(this) )
+		if ( (coll=dynamic_cast<const GeometryCollection *>(this)) )
 		{
 			ngeoms = coll->getNumGeometries();
 			for (i=0; i<ngeoms; i++)
@@ -622,7 +656,7 @@ Geometry::Union(const Geometry *other) const
 			v->push_back(this->clone());
 		}
 
-		if ( coll = dynamic_cast<const GeometryCollection *>(other) )
+		if ( (coll=dynamic_cast<const GeometryCollection *>(other)) )
 		{
 			ngeoms = coll->getNumGeometries();
 			for (i=0; i<ngeoms; i++)
@@ -896,6 +930,15 @@ Point* Geometry::createPointFromInternalCoord(const Coordinate* coord,const Geom
 
 /**********************************************************************
  * $Log: Geometry.cpp,v $
+ * Revision 1.72.2.5.2.1  2005/11/30 12:33:23  strk
+ * Updated Doxygen doc to reccommend use of the C API.
+ *
+ * Revision 1.72.2.5  2005/11/11 12:05:50  strk
+ * wrapped boolean expression in parentesis, as suggested by compiler
+ *
+ * Revision 1.72.2.4  2005/11/08 09:08:07  strk
+ * Cleaned up a couple of Doxygen warnings
+ *
  * Revision 1.72.2.3  2005/08/22 13:30:32  strk
  * Fixed comparator functions used with STL sort() algorithm to
  * implement StrictWeakOrdering semantic.
